@@ -1,4 +1,4 @@
-require File.expand_path('../../../spec_helper', __FILE__)
+require_relative '../../spec_helper'
 
 describe :rational_marshal_dump, shared: true do
   it "needs to be reviewed for spec completeness"
